#
# spec file for package yast2-proxy
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-proxy
Version:        5.0.0
Release:        1.8
Summary:        YaST2 - Proxy Configuration
License:        GPL-2.0-or-later
Group:          System/YaST
URL:            https://github.com/yast/yast-proxy

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  update-desktop-files
BuildRequires:  yast2
BuildRequires:  yast2-buildtools >= 4.2.2
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake)

Requires:       yast2
Requires:       yast2-ruby-bindings >= 1.0.0

# we split off that one
Conflicts:      yast2-network < 2.22.6

Supplements:    autoyast(proxy)

BuildArch:      noarch

%description
This package contains the YaST2 component for proxy configuration.

%prep
%setup -q

%check
%yast_check

%build

%install
%yast_install
%yast_metainfo

%files
%{yast_clientdir}
%{yast_libdir}
%{yast_moduledir}
%{yast_yncludedir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_scrconfdir}
%{yast_schemadir}
%{yast_icondir}
%license COPYING
%doc %{yast_docdir}

%changelog
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Wed Jun  9 2021 Knut Anderssen <kanderssen@suse.com>
- Added 'to_target' variable which will determine whether the
  configuration should be written to the target system at the end
  of the installation or not (bsc#1185016).
- Replace novell urls by SUSE ones (bsc#1100366)
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0 (bsc#1185510)
* Mon Aug 10 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(proxy) into the spec file
  in order to install this packages if the section has been defined
  in the AY configuration file (bsc#1146494).
- 4.3.2
* Tue Jun  9 2020 Josef Reidinger <jreidinger@suse.com>
- Reduce autoyast profile size if proxy is disabled (bsc#1172749)
- 4.3.1
* Tue May 12 2020 josef Reidinger <jreidinger@suse.com>
- Autoyast schema: Allow optional types for string and map objects
  (bsc#1170886)
- 4.3.0
* Thu Aug 22 2019 schubi@suse.de
- Using rb_default_ruby_abi tag in the spec file in order to
  handle several ruby versions (bsc#1146403).
- 4.2.2
* Thu Jul  4 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Fix 'proxy' behaviour when running in firstboot (bsc#1140199).
- 4.2.1
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.0
* Wed Dec  5 2018 jreidinger@suse.com
- always use absolute path to binaries (bsc#1118291)
- escape properly shell arguments (bsc#1118291)
- 4.1.0
* Sun Nov 25 2018 Noah Davis <noahadvs@gmail.com>
- Provide icon with module (boo#1109310)
- 4.0.3
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Wed Jun 27 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.0.2
* Thu May 10 2018 mvidner@suse.com
- Clean up the no_proxy value: not all clients ignore spaces
  (bsc#1089796)
- 4.0.1
* Fri Apr  6 2018 mfilka@suse.com
- bnc#1087957 - version bump
- 4.0.0
* Fri Jun 12 2015 mvidner@suse.com
- If PROXY_ENABLED is not set, interpret it as disabled,
  like the rest of the system does (boo#934925).
- Internal cleanups:
  - Got rid of autotools.
  - Converted legacy testsuite to RSpec.
  - Moved code out of clients for better testability.
- 3.1.6
* Thu Jun 11 2015 mvidner@suse.com
- Fixed the last change not to crash with "internal error in
  WriteCurlrc" when installing with a proxy (boo#929868).
- 3.1.5
* Thu Apr  9 2015 mvidner@suse.com
- Write also --noproxy to .curlrc otherwise it is ignored even if
  set in the environment (bsc#923788).
- 3.1.4
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Wed Oct  8 2014 mvidner@suse.com
- Fixed Test Proxy Settings always reporting failure (bnc#853725,
  bnc#871945).
- 3.1.2
* Wed Nov 13 2013 jreidinger@suse.com
- Add explicit COPYING file
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Tue Jul 16 2013 lslezak@suse.cz
- move an include statement to the top level (needed for Ruby
  translation)
- 2.24.0
* Wed Apr 11 2012 mvidner@suse.cz
- Moved over one forgotten file.
- 2.22.1
* Tue Apr 10 2012 mvidner@suse.cz
- Split off yast2-network
- 2.22.0
